@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © Thomm.o 2020
+# Copyright © Thomm.o 2021
 #
 # This file is part of Lightbulb.
 #
@@ -26,6 +26,7 @@ __all__: typing.Final[typing.List[str]] = [
     "guild_only",
     "owner_only",
     "bot_only",
+    "webhook_only",
     "human_only",
     "has_roles",
     "has_guild_permissions",
@@ -38,7 +39,6 @@ __all__: typing.Final[typing.List[str]] = [
 import functools
 import inspect
 import operator
-import types
 import typing
 
 import hikari
@@ -68,7 +68,7 @@ Invalid:
 async def foo(ctx):
     ...
 
-See https://tandemdude.gitlab.io/lightbulb/api-reference.html#module-lightbulb.checks
+See https://hikari-lightbulb.readthedocs.io/en/latest/api-reference.html#module-lightbulb.checks
 """
 
 
@@ -104,8 +104,14 @@ async def _bot_only(ctx: context.Context) -> bool:
     return True
 
 
+async def _webhook_only(ctx: context.Context) -> bool:
+    if ctx.message.webhook_id is None:
+        raise errors.WebhookOnly(f"Only a webhook can use {ctx.invoked_with}")
+    return True
+
+
 async def _human_only(ctx: context.Context) -> bool:
-    if ctx.author.is_bot:
+    if ctx.author.is_bot or ctx.message.webhook_id is not None:
         raise errors.HumanOnly(f"Only an human can use {ctx.invoked_with}")
     return True
 
@@ -148,7 +154,7 @@ async def _has_guild_permissions(ctx: context.Context, *, permissions: hikari.Pe
 
     if missing_perms:
         raise errors.MissingRequiredPermission(
-            "You are missing one or more permissions required in order to run this command", permissions=missing_perms
+            "You are missing one or more permissions required in order to run this command", missing_perms
         )
     return True
 
@@ -165,7 +171,7 @@ async def _bot_has_guild_permissions(ctx: context.Context, *, permissions: hikar
 
     if missing_perms:
         raise errors.BotMissingRequiredPermission(
-            "I am missing one or more permissions required in order to run this command", permissions=missing_perms
+            "I am missing one or more permissions required in order to run this command", missing_perms
         )
     return True
 
@@ -187,7 +193,7 @@ async def _has_permissions(ctx: context.Context, *, permissions: hikari.Permissi
 
     if missing_perms:
         raise errors.MissingRequiredPermission(
-            "You are missing one or more permissions required in order to run this command", permissions=missing_perms
+            "You are missing one or more permissions required in order to run this command", missing_perms
         )
     return True
 
@@ -210,7 +216,7 @@ async def _bot_has_permissions(ctx: context.Context, *, permissions: hikari.Perm
 
     if missing_perms:
         raise errors.MissingRequiredPermission(
-            "You are missing one or more permissions required in order to run this command", permissions=missing_perms
+            "I am missing one or more permissions required in order to run this command", missing_perms
         )
     return True
 
@@ -239,7 +245,7 @@ def dm_only() -> typing.Callable[[T_inv], T_inv]:
             @lightbulb.dm_only()
             @bot.command()
             async def foo(ctx):
-                await ctx.reply("bar")
+                await ctx.respond("bar")
     """
 
     def decorate(command: T_inv) -> T_inv:
@@ -276,6 +282,19 @@ def bot_only() -> typing.Callable[[T_inv], T_inv]:
     return decorate
 
 
+def webhook_only() -> typing.Callable[[T_inv], T_inv]:
+    """
+    A decorator that prevents a command from being used by anyone other than a webhook.
+    """
+
+    def decorate(command: T_inv) -> T_inv:
+        _check_check_decorator_above_commands_decorator(command)
+        command.add_check(_webhook_only)
+        return command
+
+    return decorate
+
+
 def human_only() -> typing.Callable[[T_inv], T_inv]:
     """
     A decorator that prevents a command from being used by anyone other than a human.
@@ -360,7 +379,7 @@ def has_guild_permissions(perm1: hikari.Permissions, *permissions: hikari.Permis
         total_perms = functools.reduce(operator.or_, (*perms, *permissions))
         command.user_required_permissions = total_perms
 
-        command.add_check(functools.partial(_bot_has_guild_permissions, permissions=total_perms))
+        command.add_check(functools.partial(_has_guild_permissions, permissions=total_perms))
         return command
 
     return decorate
@@ -473,7 +492,7 @@ def check(check_func: typing.Callable[[context.Context], typing.Coroutine[typing
             @checks.check(check_message_contains_hello)
             @bot.command()
             async def foo(ctx):
-                await ctx.reply("Bar")
+                await ctx.respond("Bar")
 
     See Also:
         :meth:`~.commands.Command.add_check`
