@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © Thomm.o 2020
+# Copyright © Thomm.o 2021
 #
 # This file is part of Lightbulb.
 #
@@ -215,7 +215,7 @@ class Bot(hikari.BotApp):
 
                 @bot.command()
                 async def ping(ctx):
-                    await ctx.reply("Pong!")
+                    await ctx.respond("Pong!")
 
         See Also:
             :meth:`~.command_handler.Bot.add_command`
@@ -241,7 +241,7 @@ class Bot(hikari.BotApp):
 
                 @bot.group()
                 async def foo(ctx):
-                    await ctx.reply("Bar")
+                    await ctx.respond("Bar")
 
         See Also:
             :meth:`~.commands.Group.command` for how to add subcommands to a group.
@@ -303,7 +303,7 @@ class Bot(hikari.BotApp):
                 bot = lightbulb.Bot(...)
 
                 async def ping(ctx):
-                    await ctx.reply("Pong!")
+                    await ctx.respond("Pong!")
 
                 bot.add_command(ping)
 
@@ -414,7 +414,7 @@ class Bot(hikari.BotApp):
             raise NameError(f"A plugin named {plugin.name} is already registered.")
 
         self.plugins[plugin.name] = plugin
-        for command in plugin.commands.values():
+        for command in plugin._commands.values():
             if isinstance(command, commands.Group):
                 self.add_group(command)
             else:
@@ -438,7 +438,18 @@ class Bot(hikari.BotApp):
         Returns:
             Optional[ :obj:`~.commands.Command` ]: Command object registered to that name.
         """
-        return self._commands.get(name)
+        tokens = name.split()
+        this = self._commands.get(tokens.pop(0))
+
+        if not tokens:
+            return this
+        if this is None:
+            return this
+
+        for token in tokens:
+            this = this.get_subcommand(token)
+
+        return this
 
     def get_plugin(self, name: str) -> typing.Optional[plugins.Plugin]:
         """
@@ -486,7 +497,7 @@ class Bot(hikari.BotApp):
         plugin.plugin_remove()
 
         if plugin is not None:
-            for k in plugin.commands.keys():
+            for k in plugin._commands.keys():
                 self.remove_command(k)
 
             for event_type, listeners in plugin.listeners.items():
@@ -530,12 +541,12 @@ class Bot(hikari.BotApp):
                     bot.add_plugin(MyPlugin())
         """
         if extension in self.extensions:
-            raise errors.ExtensionAlreadyLoaded(f"{extension} is already loaded.")
+            raise errors.ExtensionAlreadyLoaded(text=f"{extension} is already loaded.")
 
         module = importlib.import_module(extension)
 
         if not hasattr(module, "load"):
-            raise errors.ExtensionMissingLoad(f"{extension} is missing a load function")
+            raise errors.ExtensionMissingLoad(text=f"{extension} is missing a load function")
         else:
             module.load(self)
             self.extensions.append(extension)
@@ -573,12 +584,12 @@ class Bot(hikari.BotApp):
                     bot.remove_plugin("MyPlugin")
         """
         if extension not in self.extensions:
-            raise errors.ExtensionNotLoaded(f"{extension} is not loaded.")
+            raise errors.ExtensionNotLoaded(text=f"{extension} is not loaded.")
 
         module = importlib.import_module(extension)
 
         if not hasattr(module, "unload"):
-            raise errors.ExtensionMissingUnload(f"{extension} is missing an unload function")
+            raise errors.ExtensionMissingUnload(text=f"{extension} is missing an unload function")
         else:
             module.unload(self)
             self.extensions.remove(extension)
@@ -764,9 +775,10 @@ class Bot(hikari.BotApp):
         sv = stringview.StringView(raw_arg_string)
         positional_args, remainder = sv.deconstruct_str(max_parse=command.arg_details.maximum_arguments)
         if remainder and command.arg_details.kwarg_name is None and not command._allow_extra_arguments:
-            raise errors.TooManyArguments(command.name)
-        if len(positional_args) < command.arg_details.minimum_arguments:
-            raise errors.NotEnoughArguments(command.name)
+            raise errors.TooManyArguments(command)
+        if (len(positional_args) + bool(remainder)) < command.arg_details.minimum_arguments:
+            missing_args = command.arg_details.get_missing_args([*positional_args, *([remainder] if remainder else [])])
+            raise errors.NotEnoughArguments(command, missing_args)
 
         if not remainder:
             remainder = {}
@@ -807,6 +819,10 @@ class Bot(hikari.BotApp):
             return
 
         new_content = event.message.content[len(prefix) :]
+
+        if not new_content or new_content.isspace():
+            return
+
         split_args = ARG_SEP_REGEX.split(new_content, maxsplit=1)
         invoked_with, command_args = split_args[0], "".join(split_args[1:])
 
@@ -855,7 +871,7 @@ class Bot(hikari.BotApp):
             await self._dispatch_command_error_event_from_exception(ex, event.message, context, command)
             return
         except Exception as ex:
-            new_ex = errors.CommandInvocationError(text=f"{type(ex).__name__}: {ex}", original=ex)
+            new_ex = errors.CommandInvocationError(f"{type(ex).__name__}: {ex}", ex)
             await self._dispatch_command_error_event_from_exception(new_ex, event.message, context, command)
             return
 
@@ -882,7 +898,7 @@ class Bot(hikari.BotApp):
         Returns:
             ``None``
         """
-        if self.ignore_bots and event.message.author.is_bot:
+        if self.ignore_bots and not event.is_human:
             return
 
         if not event.message.content:
