@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © Thomm.o 2020
+# Copyright © Thomm.o 2021
 #
 # This file is part of Lightbulb.
 #
@@ -154,9 +154,7 @@ class SignatureInspector:
             ) and not arg.ignore:
                 self.number_positional_args += 1
 
-        self.minimum_arguments = sum(
-            1 for a in self.args.values() if not a.ignore and a.required and a.argtype != inspect.Parameter.KEYWORD_ONLY
-        )
+        self.minimum_arguments = sum(1 for a in self.args.values() if not a.ignore and a.required)
         self.maximum_arguments = (
             float("inf")
             if any(a.kind == inspect.Parameter.VAR_POSITIONAL for a in signature.parameters.values())
@@ -182,6 +180,10 @@ class SignatureInspector:
 
         return ArgInfo(ignore, argtype, annotation, required, default)
 
+    def get_missing_args(self, args: typing.List[str]) -> typing.List[str]:
+        required_command_args = [name for name, arg in self.args.items() if not arg.ignore and arg.required]
+        return required_command_args[len(args) :]
+
 
 class Command:
     """
@@ -371,7 +373,7 @@ class Command:
                 @lightbulb.owner_only()
                 @bot.command()
                 async def foo(ctx):
-                    await ctx.reply("bar")
+                    await ctx.respond("bar")
 
                 @foo.command_error()
                 async def on_foo_error(event):
@@ -470,7 +472,7 @@ class Command:
                     getattr(details.annotation, "__name__", repr(details.annotation)),
                 )
                 raise errors.ConverterFailure(
-                    f"Failed converting {arg} with converter: {getattr(details.annotation, '__name__', repr(details.annotation))}"
+                    text=f"Failed converting {arg} with converter: {getattr(details.annotation, '__name__', repr(details.annotation))}"
                 )
         return new_args
 
@@ -599,10 +601,10 @@ class Group(Command):
         """
         for command in self.subcommands:
             yield command
-            if isinstance(command, type(self)):
+            if isinstance(command, Group):
                 yield from command.walk_commands()
 
-    def add_check(self, check_func: typing.Callable[[context.Context], typing.Coroutine[None, None, bool]]) -> None:
+    def add_check(self, check_func: typing.Callable[[context_.Context], typing.Coroutine[None, None, bool]]) -> None:
         if self.inherit_checks:
             for c in self.subcommands:
                 c.add_check(check_func)
@@ -635,11 +637,11 @@ class Group(Command):
 
                 @bot.group()
                 async def foo(ctx):
-                    await ctx.reply("Invoked foo")
+                    await ctx.respond("Invoked foo")
 
                 @foo.command()
                 async def bar(ctx):
-                    await ctx.reply("Invoked foo bar")
+                    await ctx.respond("Invoked foo bar")
         """
 
         def decorate(func):
