@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © Thomm.o 2020
+# Copyright © Thomm.o 2021
 #
 # This file is part of Lightbulb.
 #
@@ -210,8 +210,8 @@ class CooldownManager:
                 # Cooldown has been activated
                 raise errors.CommandIsOnCooldown(
                     "This command is on cooldown",
-                    command=context.command,
-                    retry_in=(cooldown_bucket.start_time + cooldown_bucket.length) - time.perf_counter(),
+                    context.command,
+                    (cooldown_bucket.start_time + cooldown_bucket.length) - time.perf_counter(),
                 )
             elif cooldown_status == CooldownStatus.INACTIVE:
                 # Cooldown has not yet been activated.
@@ -258,7 +258,7 @@ def cooldown(
             @lightbulb.cooldown(10, 1, lightbulb.UserBucket)
             @bot.command()
             async def ping(ctx):
-                await ctx.reply("Pong!")
+                await ctx.respond("Pong!")
 
         This would make it so that each user can only use the ``ping`` command once every ten seconds.
     """
